@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.2';
 
 use Getopt::Long qw(:config pass_through);
 use Pod::Usage;
@@ -67,7 +67,7 @@ sub pod2pandoc {
         if (@args) {
             pandoc->require('1.12.1');
             $doc->pandoc_version( pandoc->version );
-            $doc->to_pandoc(@args);
+            print $doc->to_pandoc(@args);
         }
         else {
             print $doc->to_json, "\n";
